=============
ViewClust-Vis
=============


.. image:: https://img.shields.io/pypi/v/viewclust_vis.svg
        :target: https://pypi.python.org/pypi/viewclust_vis

.. image:: https://img.shields.io/travis/Andesha/viewclust_vis.svg
        :target: https://travis-ci.com/Andesha/viewclust_vis

.. image:: https://readthedocs.org/projects/viewclust-vis/badge/?version=latest
        :target: https://viewclust-vis.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Extension to ViewClust containing dashboard submodules and more.


* Free software: MIT license
* Documentation: https://viewclust-vis.readthedocs.io.


Features
--------

* Complete user account usage diagnosis sweet
* All users information package
* Partition perfomance dashboards
* More!

Credits
-------

* `Tyler Collins`_
* `James Desjardins`_

Developed for:

* SHARCNET_
* `Compute Canada`_

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`Tyler Collins`: https://github.com/Andesha
.. _`James Desjardins`: https://github.com/jadesjardins
.. _SHARCNET: https://www.sharcnet.ca/my/front/
.. _`Compute Canada`: https://www.computecanada.ca/
